@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.212';
+our $VERSION = '0.213';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Table - table widget with support for scrolling/paging
 
 =head1 VERSION
 
-version 0.212
+version 0.213
 
 =head1 SYNOPSIS
 
@@ -1349,11 +1349,15 @@ Go to the previous row.
 
 sub key_previous_row {
 	my $self = shift;
-	return $self unless my $win = $self->window;
-	return $self if $self->{highlight_row} <= 0;
+	return 1 unless my $win = $self->window;
+	return 1 if $self->{highlight_row} <= 0;
 
-	return $self->move_highlight(-1) if $self->highlight_visible_row >= 1;
-	return $self->scroll_highlight(-1);
+	if($self->highlight_visible_row >= 1) {
+		$self->move_highlight(-1);
+		return 1;
+	}
+	$self->scroll_highlight(-1);
+	1
 }
 
 =head2 key_next_row
@@ -1364,11 +1368,15 @@ Move to the next row.
 
 sub key_next_row {
 	my $self = shift;
-	return $self unless my $win = $self->window;
-	return $self if $self->{highlight_row} >= $self->row_count - 1;
+	return 1 unless my $win = $self->window;
+	return 1 if $self->{highlight_row} >= $self->row_count - 1;
 
-	return $self->move_highlight(1) if $self->highlight_visible_row < $win->lines - 2;
-	return $self->scroll_highlight(1);
+	if($self->highlight_visible_row < $win->lines - 2) {
+		$self->move_highlight(1);
+		return 1;
+	}
+	$self->scroll_highlight(1);
+	return 1;
 }
 
 =head2 key_first_row
@@ -1382,6 +1390,7 @@ sub key_first_row {
 	$self->{highlight_row} = 0;
 	$self->{row_offset} = 0;
 	$self->redraw;
+	1
 }
 
 =head2 key_last_row
@@ -1395,6 +1404,7 @@ sub key_last_row {
 	$self->{highlight_row} = $self->row_count - 1;
 	$self->{row_offset} = $self->row_count > $self->scroll_dimension ? -1 + $self->row_count - $self->scroll_dimension : 0;
 	$self->redraw;
+	1
 }
 
 =head2 key_previous_page
@@ -1406,6 +1416,7 @@ Go up a page.
 sub key_previous_page {
 	my $self = shift;
 	$self->scroll_highlight(-$self->scroll_dimension);
+	1;
 }
 
 =head2 key_next_page
@@ -1417,6 +1428,7 @@ Go down a page.
 sub key_next_page {
 	my $self = shift;
 	$self->scroll_highlight($self->scroll_dimension);
+	1;
 }
 
 =head2 key_next_column
@@ -1425,7 +1437,7 @@ Move to the next column.
 
 =cut
 
-sub key_next_column { }
+sub key_next_column { 1 }
 
 =head2 key_previous_column
 
@@ -1433,7 +1445,7 @@ Move to the previous column.
 
 =cut
 
-sub key_previous_column { }
+sub key_previous_column { 1 }
 
 =head2 key_first_column
 
@@ -1441,7 +1453,7 @@ Move to the first column.
 
 =cut
 
-sub key_first_column { }
+sub key_first_column { 1 }
 
 =head2 key_last_column
 
@@ -1449,7 +1461,7 @@ Move to the last column.
 
 =cut
 
-sub key_last_column { }
+sub key_last_column { 1 }
 
 =head2 key_activate
 
@@ -1477,7 +1489,7 @@ sub key_activate {
 			return blessed($ret) && $ret->isa('Future') ? $ret : Future->wrap($ret)
 		})->on_ready(sub { undef $f });
 	}
-	$self
+	1
 }
 
 =head2 key_select_toggle
@@ -1488,9 +1500,9 @@ Toggle selected row.
 
 sub key_select_toggle {
 	my $self = shift;
-	return $self unless $self->multi_select;
+	return 1 unless $self->multi_select;
 	$self->{selected}{$self->highlight_row} = $self->{selected}{$self->highlight_row} ? 0 : 1;
-	$self
+	1
 }
 
 =head1 METHODS - Filtering
